@@ -145,6 +145,8 @@ class DSMSFilePackage(SyncAgent):
         if not os.path.isdir(kwargs["local_root"]):
             os.makedirs(kwargs["local_root"])
 
+        kwargs["remote_root"] = os.path.join(kwargs["remote_root"],
+                                             self.relative_path)
         super(DSMSFilePackage, self).__init__(**kwargs)
 
     def add(self, rel_file_path):
